==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp3/kgraft-patch_SUSE-SU-2021_2352-1_15.3.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for kgraft-patch SUSE-SU-2021:2352-1
# Description: Security fixes for SUSE Linux Kernel Live Patch 15 SP3
# Source:      Security Announcement Parser v1.6.1
# Modified:    2021 Aug 05
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "kgraft-patch"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2021-July/009149.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'kgraft-patch'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2021:2352-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 3 ):
		PACKAGES = {
			'kernel-64kb': '5.3.18-59.13.1',
			'kernel-64kb-debuginfo': '5.3.18-59.13.1',
			'kernel-64kb-debugsource': '5.3.18-59.13.1',
			'kernel-64kb-devel': '5.3.18-59.13.1',
			'kernel-64kb-devel-debuginfo': '5.3.18-59.13.1',
			'kernel-default': '5.3.18-59.13.1',
			'kernel-default-base': '5.3.18-59.13.1.18.6.1',
			'kernel-default-debuginfo': '5.3.18-59.13.1',
			'kernel-default-debugsource': '5.3.18-59.13.1',
			'kernel-default-devel': '5.3.18-59.13.1',
			'kernel-default-devel-debuginfo': '5.3.18-59.13.1',
			'kernel-devel': '5.3.18-59.13.1',
			'kernel-macros': '5.3.18-59.13.1',
			'kernel-preempt': '5.3.18-59.13.1',
			'kernel-preempt-debuginfo': '5.3.18-59.13.1',
			'kernel-preempt-debugsource': '5.3.18-59.13.1',
			'kernel-zfcpdump': '5.3.18-59.13.1',
			'kernel-zfcpdump-debuginfo': '5.3.18-59.13.1',
			'kernel-zfcpdump-debugsource': '5.3.18-59.13.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp3/kgraft-patch_SUSE-SU-2021_1755-1_15.3.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for kgraft-patch SUSE-SU-2021:1755-1
# Description: Security fixes for SUSE Linux Kernel Live Patch 15 SP3
# Source:      Security Announcement Parser v1.6.1
# Modified:    2021 Jun 01
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "kgraft-patch"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2021-May/008817.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'kgraft-patch'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2021:1755-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 3 ):
		PACKAGES = {
			'libu2f-host-debuginfo': '1.1.10-3.9.1',
			'libu2f-host-debugsource': '1.1.10-3.9.1',
			'libu2f-host-devel': '1.1.10-3.9.1',
			'libu2f-host0': '1.1.10-3.9.1',
			'libu2f-host0-debuginfo': '1.1.10-3.9.1',
			'u2f-host': '1.1.10-3.9.1',
			'u2f-host-debuginfo': '1.1.10-3.9.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
